# Customise Assistant Name Display

From version: 0.2.54

1. Enter '.editconfigs' in FreeGenius prompt

2. Edit the following items:

appName

text2art_font1

text2art_font1

3. Save and Exit the built-in editor

Read available fonts at: https://github.com/sepandhaghighi/art